@@ -18,7 +18,7 @@ class SubDemo(Module):
     args: An optional dictionary representing all module args, their types and their values.
   """
 
-  def __init__(self, context, args):
+  def __init__(self, context, args=None):
     super().__init__(filepath=__file__, context=context, args=args)
 
   def _get_list(self, size):
